Существуют три стратегии выбора случайной композиции из плейлиста:

- default, при которой выбирается полностью случайная песня;
- fresh, при которой выбирается случайная из пяти самых свежих песен;
- oldest, при которой выбирается песня, которая дольше всего не играла.

Пример плейлиста для проигрывания одной старой песни каждый час:

    - name: forgotten
      labels: [music]
      delay: 59
      strategy: oldest
